diff OrthancServer/ServerIndex.cpp @ 62:a70bb32802ae orthanc-renaming

renaming Server
author Sebastien Jodogne <s.jodogne@gmail.com>
date Sun, 16 Sep 2012 09:33:19 +0200
parents 4bc019d2f969
children b8dfde8d64e8
line wrap: on
line diff
--- a/OrthancServer/ServerIndex.cpp	Sun Sep 16 09:30:31 2012 +0200
+++ b/OrthancServer/ServerIndex.cpp	Sun Sep 16 09:33:19 2012 +0200
@@ -1,5 +1,5 @@
 /**
  * Palanthir - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium
  *
@@ -20,7 +20,7 @@
 
 #include "ServerIndex.h"
 
-using namespace Palanthir;
+using namespace Orthanc;
 
 #ifndef NOMINMAX
 #define NOMINMAX
@@ -36,7 +36,7 @@
 #include <boost/lexical_cast.hpp>
 #include <stdio.h>
 
-namespace Palanthir
+namespace Orthanc
 {
   namespace Internals
   {
@@ -109,7 +109,7 @@
         case 3:
           return "series";
         default:
-          throw PalanthirException(ErrorCode_InternalError);
+          throw OrthancException(ErrorCode_InternalError);
         }
       }
 
@@ -526,7 +526,7 @@
       return StoreStatus_Success;
       //t.Rollback();
     }
-    catch (PalanthirException& e)
+    catch (OrthancException& e)
     {
       std::cout << "EXCEPT2 [" << e.What() << "]" << " " << db_.GetErrorMessage() << std::endl;  
     }
@@ -1,5 +1,5 @@
 /**
- * Palanthir - A Lightweight, RESTful DICOM Store
+ * Orthanc - A Lightweight, RESTful DICOM Store
  * Copyright (C) 2012 Medical Physics Department, CHU of Liege,
  * Belgium